<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
        <source>Passwords do not match</source>
        <translation>Les contrasenyes no coincideixen.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>La pista és visible per a tots els usuaris. No inclogueu aquí la contrasenya.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
        <source>New Password</source>
        <translation>Contrasenya nova</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <source>Repeat Password</source>
        <translation>Repetiu-la.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
        <source>Password Hint</source>
        <translation>Pista per a la contrasenya</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Password cannot be empty</source>
        <translation>La contrasenya no pot estar en blanc.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Password must have at least %1 characters</source>
        <translation>La contrasenya ha de tenir com a mínim %1 caràcters.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
        <source>Password must be no more than %1 characters</source>
        <translation>La contrasenya no ha de tenir més de %1 caràcters.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>La contrasenya només pot contenir caràcters en anglès (majúscules o minúscules), números o símbols especials (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/).</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Com a màxim %1 caràcters palíndroms, si us plau.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Com a màxim %1 caràcters monòtons, si us plau.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Com a màxim %1 caràcters repetits, si us plau.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>The password should differ from the username</source>
        <translation>La contrasenya hauria de diferir del nom d&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>La contrasenya ha de tenir lletres majúscules, minúscules, números i símbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/).</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>La contrasenya no ha de contenir més de 4 caràcters palíndroms.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
        <source>Do not use common words and combinations as password</source>
        <translation>No useu paraules i combinacions habituals com a contrasenya.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
        <source>Create a strong password please</source>
        <translation>Si us plau, creeu una contrasenya forta.</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
        <source>It does not meet password rules</source>
        <translation>No compleix les regles de la contrasenya.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
        <source>It cannot be empty</source>
        <translation>No es pot deixar en blanc.</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Restablir la contrasenya esborrarà les dades emmagatzemades al clauer.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
        <source>Security Questions</source>
        <translation>Preguntes de seguretat</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
        <source>Reset Password</source>
        <translation>Restableix la contrasenya</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
        <source>Reset Password By UOS ID</source>
        <translation>Restableix la contrasenya amb l&apos;ID d&apos;UOS..</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
        <source>Reset</source>
        <translation>Restableix</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Restablir la contrasenya eliminarà les dades emmagatzemades al clauer i haureu d&apos;iniciar sessió de nou. Si us plau, deseu els fitxers amb antelació.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <source>Confirm and Reset</source>
        <translation>Confirmeu-ho i reinicieu</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Restabliment correcte. Inicieu la sessió i desbloqueu-la amb la contrasenya nova.</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
        <source>Weak</source>
        <translation>Dèbil</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
        <source>Medium</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
        <source>Strong</source>
        <translation>Forta</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Com es deia la ciutat on vau néixer?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>Com es deia la primera escola on vau anar?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>Who do you love the most in this world?</source>
        <translation>Qui estimeu més en aquest món?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Quin és el vostre animal favorit?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Quina és la vostra cançó favorita?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your nickname?</source>
        <translation>Quin sobrenom teniu?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
        <source>Wrong answer</source>
        <translation>Resposta incorrecta</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Mantingueu la resposta en menys de 30 caràcters.</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
        <source>Phone/Email</source>
        <translation>Telèfon / adreça electrònica</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
        <source>Get Code</source>
        <translation>Obtén el codi</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
        <source>Connecting to the Internet...</source>
        <translation>Es connecta a Internet...</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
        <source>The user account is not linked to UOS ID</source>
        <translation>El compte d&apos;usuari no està enllaçat amb l&apos;identificador d&apos;UOS.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Xarxa desconnectada. Si us plau, torneu-ho a intentar després de connectar-hi.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
        <source>Required</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
        <source>Phone/Email format is incorrect</source>
        <translation>El format de l&apos;adreça electrònica o del telèfon no és correcte.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>System error</source>
        <translation>Error del sistema</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation>L&apos;inici de sessió ha caducat, torneu a iniciar la sessió a l&apos;identificador d&apos;UOS.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
        <source>Network error</source>
        <translation>Error de xarxa</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Heu arribat al límit per obtenir el codi avui.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation>L&apos;identificador d&apos;UOS no està enllaçat a cap compte d&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
        <source>Resend (%1s)</source>
        <translation>Torna-ho a enviar (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
        <source>Failed to get the code</source>
        <translation>Ha fallat obtenir el codi.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
        <source>Wrong verification code</source>
        <translation>Codi de verificació incorrecte</translation>
    </message>
</context>
</TS>